@@ -82,7 +82,7 @@ public:
     virtual void OnRspOrderAction(CThostFtdcInputOrderActionField *pInputOrderAction, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
     ///查询最大报单数量响应
-    virtual void OnRspQueryMaxOrderVolume(CThostFtdcQueryMaxOrderVolumeField *pQueryMaxOrderVolume, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+    virtual void OnRspQryMaxOrderVolume(CThostFtdcQryMaxOrderVolumeField *pQryMaxOrderVolume, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
     ///投资者结算结果确认响应
     virtual void OnRspSettlementInfoConfirm(CThostFtdcSettlementInfoConfirmField *pSettlementInfoConfirm, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
@@ -410,6 +410,12 @@ public:
 
     ///银行发起变更银行账号通知
     virtual void OnRtnChangeAccountByBank(CThostFtdcChangeAccountField *pChangeAccount) {};
+
+    ///请求查询分类合约响应
+    virtual void OnRspQryClassifiedInstrument(CThostFtdcInstrumentField *pInstrument, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
+    ///请求组合优惠比例响应
+    virtual void OnRspQryCombPromotionParam(CThostFtdcCombPromotionParamField *pCombPromotionParam, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 };
 
 class TRADER_API_EXPORT CThostFtdcTraderApi {
@@ -474,6 +480,7 @@ public:
     ///        THOST_TERT_RESTART:从本交易日开始重传
     ///        THOST_TERT_RESUME:从上次收到的续传
     ///        THOST_TERT_QUICK:只传送登录后公共流的内容
+    ///        THOST_TERT_NONE:取消订阅公共流
     ///@remark 该方法要在Init方法前调用。若不调用则不会收到公共流的数据。
     virtual void SubscribePublicTopic(THOST_TE_RESUME_TYPE nResumeType) = 0;
 
@@ -531,7 +538,7 @@ public:
     virtual int ReqOrderAction(CThostFtdcInputOrderActionField *pInputOrderAction, int nRequestID) = 0;
 
     ///查询最大报单数量请求
-    virtual int ReqQueryMaxOrderVolume(CThostFtdcQueryMaxOrderVolumeField *pQueryMaxOrderVolume, int nRequestID) = 0;
+    virtual int ReqQryMaxOrderVolume(CThostFtdcQryMaxOrderVolumeField *pQryMaxOrderVolume, int nRequestID) = 0;
 
     ///投资者结算结果确认
     virtual int ReqSettlementInfoConfirm(CThostFtdcSettlementInfoConfirmField *pSettlementInfoConfirm, int nRequestID) = 0;
@@ -731,6 +738,12 @@ public:
     ///期货发起查询银行余额请求
     virtual int ReqQueryBankAccountMoneyByFuture(CThostFtdcReqQueryAccountField *pReqQueryAccount, int nRequestID) = 0;
 
+    ///请求查询分类合约
+    virtual int ReqQryClassifiedInstrument(CThostFtdcQryClassifiedInstrumentField *pQryClassifiedInstrument, int nRequestID) = 0;
+
+    ///请求组合优惠比例
+    virtual int ReqQryCombPromotionParam(CThostFtdcQryCombPromotionParamField *pQryCombPromotionParam, int nRequestID) = 0;
+
 protected:
     ~CThostFtdcTraderApi() {};
 };
